@@ -266,3 +266,9 @@ test_that("translate sql server -> sqlite ALTER TABLE ADD multiple", {
   sql <- translate("ALTER TABLE my_table ADD a INT, b INT, c VARCHAR(255);", targetDialect = "sqlite")
   expect_equal_ignore_spaces(sql, "ALTER TABLE my_table ADD a INT; ALTER TABLE my_table ADD b INT; ALTER TABLE my_table ADD c TEXT;")
 })
+
+test_that("translate sql server -> sqlite ALTER TABLE ADD COLUMN", {
+  # Note: this is incorrect OhdsiSql, but included for legacy reasons (https://github.com/OHDSI/CohortDiagnostics/issues/1080)
+  sql <- translate("ALTER TABLE my_table ADD COLUMN a INT;", targetDialect = "sqlite")
+  expect_equal_ignore_spaces(sql, "ALTER TABLE my_table ADD COLUMN a INT;")
+})
